#ifndef _LCT_FONT_H
#define _LCT_FONT_H

#include <stdio.h>
#include <linux/kd.h>

#include <lct/unicode.h>
#include <lct/utils.h>

/*
 * Font data stuff
 */

/* fontdata.c */
int fontdata_write_binary (FILE* out, struct consolefontdesc *cfd);
int fontdata_read_binary  (FILE* in, struct consolefontdesc *cfd);

/*
 * SFM stuff
 */

struct unicode_list
{
  unicode uc;			/* Unicode listed */
  struct unicode_list *next;
};

/* unimap-*.c */
int sfm_read_ascii   (FILE*, struct unimapdesc*, int fontlen);
int sfm_read_binary  (FILE*, struct unimapdesc*, int fontlen);
int sfm_write_ascii  (FILE*, struct unimapdesc*);
int sfm_write_binary (FILE*, struct unimapdesc*, int fontlen);

/*
 * Unifont stuff
 */

/* file-formats identification */

#define FFF_RAW		1
#define FFF_CP		2
#define FFF_PSF		3
#define FFF_XPSF	4

extern const struct magicset ff_magics;

/* core unifont stuff */

typedef struct unifont
{
  struct consolefontdesc font;
  struct unimapdesc sfm;
  FILE* fontfile;
  FILE* sfmfile;
  char mode;
  int ffformat;
} simple_font;

/*
 * PSF stuff
 */

#define PSF_MAGIC1	0x36
#define PSF_MAGIC2	0x04

#define PSF_MODE512	( 1 << 0 )
#define PSF_MODEHASTAB	( 1 << 1 )
#define PSF_MAXMODE	( PSF_MODE512 | PSF_MODEHASTAB )

#define PSF_SEPARATOR	0xFFFF

struct psf_header
{
  unsigned char magic1, magic2;	/* Magic number */
  unsigned char mode;		/* PSF font mode */
  unsigned char charsize;	/* Character size */
};

#define PSF_MAGIC_OK(x)	((x).magic1 == PSF_MAGIC1 && (x).magic2 == PSF_MAGIC2)

/* psf-header.c */
int psf_header_read     (FILE* in, struct psf_header* psfhdr_ptr);
int psf_header_write    (FILE* out, struct psf_header* psfhdr_ptr);
int write_as_psf_header (FILE* out, int charsize, int charcount, int with_sfm);

#endif /* _LCT_FONT_H */
